git@vger.kernel.org mailing list mirror (one of many)
 help / color / mirror / code / Atom feed
From: Michael Haggerty <mhagger@alum.mit.edu>
To: Junio C Hamano <gitster@pobox.com>
Cc: Stefan Beller <sbeller@google.com>,
	Eric Sunshine <sunshine@sunshineco.com>,
	Jeff King <peff@peff.net>,
	git@vger.kernel.org, Michael Haggerty <mhagger@alum.mit.edu>
Subject: [PATCH v2 11/18] verify_refname_available(): rename function
Date: Mon, 11 May 2015 17:25:13 +0200	[thread overview]
Message-ID: <1431357920-25090-12-git-send-email-mhagger@alum.mit.edu> (raw)
In-Reply-To: <1431357920-25090-1-git-send-email-mhagger@alum.mit.edu>

Rename is_refname_available() to verify_refname_available() and change
its return value from 1 for success to 0 for success, to be consistent
with our error-handling convention. In a moment it will also get a
"struct strbuf *err" parameter.

Signed-off-by: Michael Haggerty <mhagger@alum.mit.edu>
---
 refs.c | 37 ++++++++++++++++++++-----------------
 1 file changed, 20 insertions(+), 17 deletions(-)

diff --git a/refs.c b/refs.c
index 0fa70fb..703e93d 100644
--- a/refs.c
+++ b/refs.c
@@ -263,7 +263,7 @@ struct ref_dir {
  * presence of an empty subdirectory does not block the creation of a
  * similarly-named reference.  (The fact that reference names with the
  * same leading components can conflict *with each other* is a
  * separate issue that is regulated by is_refname_available().)
  *
  * Please note that the name field contains the fully-qualified
  * reference (or subdirectory) name.  Space could be saved by only
@@ -858,13 +858,14 @@ static int nonmatching_ref_fn(struct ref_entry *entry, void *vdata)
 }
 
 /*
- * Return true iff a reference named refname could be created without
- * conflicting with the name of an existing reference in dir. If
- * extras is non-NULL, it is a list of additional refnames with which
- * refname is not allowed to conflict. If skip is non-NULL, ignore
- * potential conflicts with refs in skip (e.g., because they are
- * scheduled for deletion in the same operation). Behavior is
- * undefined if the same name is listed in both extras and skip.
+ * Return 0 if a reference named refname could be created without
+ * conflicting with the name of an existing reference in dir.
+ * Otherwise, return a negative value. If extras is non-NULL, it is a
+ * list of additional refnames with which refname is not allowed to
+ * conflict. If skip is non-NULL, ignore potential conflicts with refs
+ * in skip (e.g., because they are scheduled for deletion in the same
+ * operation). Behavior is undefined if the same name is listed in
+ * both extras and skip.
  *
  * Two reference names conflict if one of them exactly matches the
  * leading components of the other; e.g., "refs/foo/bar" conflicts
@@ -873,15 +874,15 @@ static int nonmatching_ref_fn(struct ref_entry *entry, void *vdata)
  *
  * extras and skip must be sorted.
  */
-static int is_refname_available(const char *refname,
-				const struct string_list *extras,
-				const struct string_list *skip,
-				struct ref_dir *dir)
+static int verify_refname_available(const char *refname,
+				    const struct string_list *extras,
+				    const struct string_list *skip,
+				    struct ref_dir *dir)
 {
 	const char *slash;
 	int pos;
 	struct strbuf dirname = STRBUF_INIT;
-	int ret = 0;
+	int ret = -1;
 
 	/*
 	 * For the sake of comments in this function, suppose that
@@ -1007,7 +1008,7 @@ static int is_refname_available(const char *refname,
 	}
 
 	/* No conflicts were found */
-	ret = 1;
+	ret = 0;
 
 cleanup:
 	strbuf_release(&dirname);
@@ -2383,7 +2384,7 @@ static struct ref_lock *lock_ref_sha1_basic(const char *refname,
 	 * our refname.
 	 */
 	if (is_null_sha1(lock->old_sha1) &&
-	    !is_refname_available(refname, extras, skip, get_packed_refs(&ref_cache))) {
+	    verify_refname_available(refname, extras, skip, get_packed_refs(&ref_cache))) {
 		last_errno = ENOTDIR;
 		goto error_return;
 	}
@@ -2824,8 +2825,10 @@ static int rename_ref_available(const char *oldname, const char *newname)
 	int ret;
 
 	string_list_insert(&skip, oldname);
-	ret = is_refname_available(newname, NULL, &skip, get_packed_refs(&ref_cache))
-		&& is_refname_available(newname, NULL, &skip, get_loose_refs(&ref_cache));
+	ret = !verify_refname_available(newname, NULL, &skip,
+					get_packed_refs(&ref_cache))
+		&& !verify_refname_available(newname, NULL, &skip,
+					     get_loose_refs(&ref_cache));
 	string_list_clear(&skip, 0);
 	return ret;
 }
@@ -263,7 +263,7 @@ struct ref_dir {
  * similarly-named reference.  (The fact that reference names with the
  * same leading components can conflict *with each other* is a
- * separate issue that is regulated by is_refname_available().)
+ * separate issue that is regulated by verify_refname_available().)
  *
  * Please note that the name field contains the fully-qualified
-- 
2.1.4

  parent reply	other threads:[~2015-05-11 15:26 UTC|newest]

Thread overview: 33+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2015-05-11 15:25 [PATCH v2 00/18] Improve handling of D/F conflicts Michael Haggerty
2015-05-11 15:25 ` [PATCH v2 01/18] t1404: new tests of ref D/F conflicts within transactions Michael Haggerty
2015-05-11 18:52   ` Junio C Hamano
2015-05-12  8:45     ` Michael Haggerty
2015-05-11 19:37   ` Junio C Hamano
2015-05-12  8:32     ` Michael Haggerty
2015-05-12 15:45       ` Junio C Hamano
2015-05-13 20:19         ` Michael Haggerty
2015-05-14 17:00           ` Junio C Hamano
2015-05-22 22:47             ` Michael Haggerty
2015-05-23  0:52               ` Junio C Hamano
2015-05-11 15:25 ` [PATCH v2 02/18] is_refname_available(): revamp the comments Michael Haggerty
2015-05-12 21:04   ` Junio C Hamano
2015-05-11 15:25 ` [PATCH v2 03/18] is_refname_available(): avoid shadowing "dir" variable Michael Haggerty
2015-05-12 21:06   ` Junio C Hamano
2015-05-11 15:25 ` [PATCH v2 04/18] is_refname_available(): convert local variable "dirname" to strbuf Michael Haggerty
2015-05-11 15:25 ` [PATCH v2 05/18] entry_matches(): inline function Michael Haggerty
2015-05-11 15:25 ` [PATCH v2 06/18] report_refname_conflict(): " Michael Haggerty
2015-05-12 21:21   ` Junio C Hamano
2015-05-11 15:25 ` [PATCH v2 07/18] struct nonmatching_ref_data: store a refname instead of a ref_entry Michael Haggerty
2015-05-11 15:25 ` [PATCH v2 08/18] is_refname_available(): use dirname in first loop Michael Haggerty
2015-05-11 15:25 ` [PATCH v2 09/18] ref_transaction_commit(): use a string_list for detecting duplicates Michael Haggerty
2015-05-11 15:25 ` [PATCH v2 10/18] refs: check for D/F conflicts among refs created in a transaction Michael Haggerty
2015-05-11 15:25 ` Michael Haggerty [this message]
2015-05-11 15:25 ` [PATCH v2 12/18] verify_refname_available(): report errors via a "struct strbuf *err" Michael Haggerty
2015-05-11 15:25 ` [PATCH v2 13/18] lock_ref_sha1_basic(): " Michael Haggerty
2015-05-11 15:25 ` [PATCH v2 14/18] lock_ref_sha1_basic(): improve diagnostics for ref D/F conflicts Michael Haggerty
2015-05-11 15:25 ` [PATCH v2 15/18] rename_ref(): integrate lock_ref_sha1_basic() errors into ours Michael Haggerty
2015-05-11 15:25 ` [PATCH v2 16/18] ref_transaction_commit(): provide better error messages Michael Haggerty
2015-05-11 15:25 ` [PATCH v2 17/18] ref_transaction_commit(): delete extra "the" from error message Michael Haggerty
2015-05-11 15:25 ` [PATCH v2 18/18] reflog_expire(): integrate lock_ref_sha1_basic() errors into ours Michael Haggerty
2015-05-11 17:56 ` [PATCH v2 00/18] Improve handling of D/F conflicts Junio C Hamano
2015-05-11 18:10   ` Stefan Beller

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: http://vger.kernel.org/majordomo-info.html

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1431357920-25090-12-git-send-email-mhagger@alum.mit.edu \
    --to=mhagger@alum.mit.edu \
    --cc=git@vger.kernel.org \
    --cc=gitster@pobox.com \
    --cc=peff@peff.net \
    --cc=sbeller@google.com \
    --cc=sunshine@sunshineco.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://80x24.org/mirrors/git.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).